package org.artifactory.metrics.framework.providers;

import org.artifactory.storage.service.StorageMetric;
import org.artifactory.storage.service.StorageMetricCollector;
import org.jfrog.metrics.model.Metric;
import org.jfrog.metrics.model.MetricProvider;

import java.util.ArrayList;
import java.util.List;

import static org.artifactory.metrics.framework.providers.util.ProviderUtil.addMetricToList;

public class StorageMetricProvider implements MetricProvider {

    private final StorageMetricCollector collector;

    public StorageMetricProvider(StorageMetricCollector collector) {
        this.collector = collector;
    }

    @Override
    public String getName() {
        return "jfrt_storage";
    }

    @Override
    public String getDescription() {
        return "Artifactory Storage Metric Provider";
    }

    @Override
    public long getRefreshIntervalMillis() {
        return 0;
    }

    @Override
    public List<Metric> collect() {
        StorageMetric currentMetric = collector.get();
        List<Metric> metrics = new ArrayList<>();
        addMetricToList(metrics, "current_total_size", Metric.MetricType.BYTES, "Used Storage",
                currentMetric.getStorageSize());
        return metrics;
    }

    @Override
    public ReportType getReportType() {
        return ReportType.CONTINUOUS;
    }

    @Override
    public long getLastUpdatedMillis() {
        return 0;
    }

}
