package org.artifactory.projects;

import lombok.NonNull;
import org.jfrog.access.client.AccessClientException;
import org.jfrog.access.client.project.ProjectResourceEntity;
import org.jfrog.access.common.EnvironmentsConstants;

import javax.annotation.Nullable;
import java.util.List;
import java.util.Set;

/**
 * @author BarakH
 */
public interface ProjectsService {

    String PROJECT = "project";
    String DEFAULT_PROJECT = "default";
    String ENVIRONMENTS = "environments";
    String ENV_DEV = EnvironmentsConstants.DEV;
    String ENV_PROD = EnvironmentsConstants.PROD;
    String DEFAULT_ENVIRONMENT = ENV_DEV;
    List<String> GLOBAL_ENVIRONMENTS = List.of(ENV_PROD, ENV_DEV);
    long UNLIMITED_STORAGE = -1L;

    /**
     * Add a new repository to the given project and environment
     */
    default void addProjectRepository(String project, Set<String> environments, String repoKey) throws
            AccessClientException {
    }

    /**
     * Remove a repo resource from its current project
     */
    default void removeRepositoryFromCurrentProject(String repoKey) throws AccessClientException {
    }

    /**
     * @return A list with all the projects the user has ProjectAdmin role on.
     */
    @NonNull
    List<String> getAllProjectsManagedByUser();

    /**
     * @return A list with all the projects
     */
    @NonNull
    List<String> getAllProjects();

    /**
     * @return A list of all the project repositories
     */
    @NonNull
    Set<String> getProjectRepositories(String project, boolean ignoreCache);

    /**
     * @return A set of all the repositories the user has admin role over
     */
    @NonNull
    Set<String> getProjectAdminRepositories();

    /**
     * @return The repository project name or default project if none
     */
    @NonNull
    String getProjectOfRepository(String repoKey);

    @Nullable
    ProjectResourceEntity getProjectRepositoryEntity(@NonNull String projectName, @NonNull String repoKey,
            boolean ignoreCache);

    /**
     * @throws IllegalArgumentException if the repo key is not matching to the given project prefix or the
     *                                  environments are not configured for the project.
     */
    default void validateRepoConfigIsMatchingToProjectSpec(String project, String repoKey, Set<String> environments) {

    }

    /**
     * @return The project storage quota limit in bytes or {@link #UNLIMITED_STORAGE} if failed to find the project
     */
    long getProjectStorageQuotaBytes(String project);
}
