package org.artifactory.projects;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import lombok.NonNull;
import org.apache.commons.lang.StringUtils;
import org.artifactory.util.CollectionUtils;

import javax.annotation.Nullable;
import java.util.List;
import java.util.Set;

/**
 * @author BarakH
 */
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class ProjectsUtils {

    public static boolean isDefaultProject(@Nullable String project) {
        return StringUtils.isEmpty(project) || ProjectsService.DEFAULT_PROJECT.equalsIgnoreCase(project);
    }

    /**
     * @throws IllegalArgumentException if the given project does not contain all the virtual repositories
     */
    public static void assertVirtualRepositoriesAreInProject(@NonNull ProjectsService projectsService,
            @Nullable String project, @Nullable List<String> virtualRepositories) throws IllegalArgumentException {
        if (isDefaultProject(project) || CollectionUtils.isNullOrEmpty(virtualRepositories)) {
            return;
        }
        Set<String> projectRepositories = projectsService.getProjectRepositories(project, false);
        if (!projectRepositories.containsAll(virtualRepositories)) {
            throw new IllegalArgumentException(
                    "Virtual repository must include only repositories from the same project it was created with");
        }
    }
}
