package org.artifactory.projects;

import org.apache.commons.lang3.builder.DiffBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import org.artifactory.config.CentralConfigKey;
import org.testng.Assert;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

/**
 * @author BarakH
 */
@Test
public class ProjectAdminValidatorImplTest {

    private final ProjectAdminValidatorImpl projectAdminValidator = new ProjectAdminValidatorImpl();

    @Test(dataProvider = "provideFieldNames")
    public void testIsProjectAdminAllowedToSaveConfigChanges(String fieldName, boolean shouldBeAllowed) {
        DiffBuilder db = new DiffBuilder("a", "b", ToStringStyle.DEFAULT_STYLE, false);
        db.append(fieldName, "a", "b");
        if (!shouldBeAllowed) {
            Assert.assertThrows(IllegalArgumentException.class,
                    () -> projectAdminValidator.verifyConfigChangesAllowed(db.build()));
        } else {
            projectAdminValidator.verifyConfigChangesAllowed(db.build());
        }
    }

    @DataProvider
    public static Object[][] provideFieldNames() {
        return new Object[][] {
                {CentralConfigKey.localRepositoriesMap.getKey(), true},
                {CentralConfigKey.remoteRepositoriesMap.getKey(), true},
                {CentralConfigKey.virtualRepositoriesMap.getKey(), true},
                {CentralConfigKey.distributionRepositoriesMap.getKey(), true},
                {CentralConfigKey.releaseBundlesRepositoriesMap.getKey(), true},
                {"repoLayouts", true},
                {CentralConfigKey.localReplications.getKey(), false},
                {"", false},
                {null, false},
        };
    }
}
