#!/usr/bin/env bash

set -e

export PROJECT_ROOT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && cd ../../.. && pwd)"
source "${PROJECT_ROOT_DIR}/build/ci/scripts/lib/buildInfoUtils.sh"
source "${PROJECT_ROOT_DIR}/build/ci/scripts/lib/versionUtils.sh"
source "${PROJECT_ROOT_DIR}/build/ci/scripts/lib/mavenUtils.sh"

cd "${PROJECT_ROOT_DIR}/artifactory-oss"


function on_start() {
  local projectListArg
  local version revision
  version=$(maven_getVersionFromPom pom.xml)
  revision=$(version_getRevisionFromVersion ${version})
  export MAVEN_EXTRA_CONFIG="${MAVEN_CONFIG} -s ${PROJECT_ROOT_DIR}/build/ci/.conf/settings.xml -Dartifactory.revision.prop=${revision}"
  "${PROJECT_ROOT_DIR}/build/ci/scripts/javaGenerateConfig.sh"
  buildInfo_setBuildNameAndNumber
  projectListArg="$(getMavenProjectListArg)"
  export MVN_COMMAND="install ${projectListArg} -DskipTests ${MAVEN_EXTRA_CONFIG}"
}

function on_success() {
  local version
  version=$(maven_getVersionFromPom "pom.xml")
  buildInfo_modifyBuildName "${JFROG_CLI_BUILD_NAME}" "${JFROG_CLI_BUILD_NUMBER}"
  buildInfo_publish
  write_output artifactory_oss_java_module_build_info buildName="${JFROG_CLI_BUILD_NAME}" buildNumber="${JFROG_CLI_BUILD_NUMBER}" version="${version}"
}

function getMavenProjectListArg() {
  local projectList
  projectList="!org.artifactory.oss:jfrog-artifactory-server-xml-template,!org.artifactory.oss.docker:jfrog-artifactory-oss,!org.artifactory.oss.docker:artifactory-oss-docker,!org.artifactory.oss.rpm:jfrog-artifactory-oss,!org.artifactory.oss.deb:jfrog-artifactory-oss"
  if [[ -n "$projectList" ]]; then
    echo "-pl='${projectList}'"
  fi
}